@@ -9,12 +9,12 @@ from trytond.modules.company.model import CompanyValueMixin
 __all__ = ['Configuration', 'ConfigurationDefaultCreditLimitAmount', 'Level']
 default_credit_limit_amount = fields.Numeric(
     "Default Credit Limit Amount",
+    help="The default credit limit amount for new customers.",
     digits=(16, Eval('default_credit_limit_amount_digits', 2)),
     depends=['default_credit_limit_amount_digits'])
 
 
-class Configuration:
-    __metaclass__ = PoolMeta
+class Configuration(metaclass=PoolMeta):
     __name__ = 'account.configuration'
 
     default_credit_limit_amount = fields.MultiValue(
@@ -46,8 +46,7 @@ class ConfigurationDefaultCreditLimitAmount(ModelSQL, CompanyValueMixin):
             return self.company.currency.digits
 
 
-class Level:
-    __metaclass__ = PoolMeta
+class Level(metaclass=PoolMeta):
     __name__ = 'account.dunning.level'
     credit_limit = fields.Boolean('Credit Limit',
         help='Has reached the credit limit')
